@@ -3,6 +3,7 @@
 import _mysql
 from torndb import Row
 from cache import mc as _mc
+from lerry_signal import SIGNAL
 from torndb import Connection as _Connection
 from msgpack import packb, unpackb
 
@@ -12,10 +13,10 @@ class Model(object):
 	def KEY(self, id):
 		return '%s:%s' % (self._table, id)
 
-	def __init__(self, name, db, mc):
+	def __init__(self, name, db):
 		self._table = name
 		self.db = db
-		self.mc = mc
+		self.mc = db.mc
 
 	def get(self, id):
 		id = int(id)
@@ -23,7 +24,7 @@ class Model(object):
 		item = self.mc.get(MC_KEY)
 		if item is None:
 			item = self.db.get('select * from %s where id = %%s' % self._table, id)
-			mc.set(MC_KEY, packb(item))
+			self.mc.set(MC_KEY, packb(item))
 		else:
 			item = Row(unpackb(item))
 		return item
@@ -40,21 +41,33 @@ class Model(object):
 		return map(Row, result)
 
 	def rm(self, id):
-		db.query('delete from %s where id = %%s' % self._table, id)
-		mc.delete('%s:%s' % (self._table, id))
+		self.db.query('delete from %s where id = %%s' % self._table, id)
+		self.mc.delete('%s:%s' % (self._table, id))
 
 def _getattr(self, name):
 	self.query('select 1 from %s' % name)
-	return Model(name, self, mc)
+	return Model(name, self)
 
+def _execute(self, cursor, query, parameters):
+    try:
+        result = cursor.execute(query, parameters)
+        SIGNAL.db_query.send(cursor._last_executed)
+        return result
+    except OperationalError:
+        logging.error("Error connecting to MySQL on %s", self.host)
+        self.close()
+        raise
 
-class Connection(object):
-	def __init__(self, host, db, user, pw, mc=None):
-		pass
-		if mc is None:
-			mc = _mc
-		_Connection.__getattr__ = _getattr
-		return _Connection(host, db, user, pw)
+def Connection(host, db, user, pw, mc=None):
+	'''
+		wrapper of torndb
+	'''
+	if mc is None:
+		mc = _mc
+	_Connection.__getattr__ = _getattr
+	_Connection.mc = mc
+	_Connection._execute = _execute
+	return _Connection(host, db, user, pw)
 		
 
 
